/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
#define _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_

#include "BioStruct3DGLRender.h"

namespace U2 { 

    class VanDerWaalsGLRenderer : public BioStruct3DGLRenderer {


        void drawAtoms(const BioStruct3DColorScheme* s);
       
        bool displayListsExist;

    public:

        VanDerWaalsGLRenderer(const BioStruct3D& struc, const BioStruct3DColorScheme* s); 

        void drawBioStruct3D();

        RENDERER_FACTORY(VanDerWaalsGLRenderer)

    };

} //namespace

#endif // _U2_BIOSTRUCT3D_VANDERWAALS_RENDERER_H_
